==> ejc-rmat-impl-3.0.0-20210811.084257-59-sources.jar: com/ejianc/business/rmat/service/impl/RentSettlementBpmServiceImpl.java <==
package com.ejianc.business.rmat.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.ejianc.business.rmat.bean.RentContractEntity;
import com.ejianc.business.rmat.bean.RentSettlementEntity;
import com.ejianc.business.rmat.service.IRentContractService;
import com.ejianc.business.rmat.service.IRentSettlementService;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.response.BillStateEnum;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.billState.service.ICommonBusinessService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;

/**
 * <p>
 * 设备合同结算单审批操作后
 * </p>
 *
 * @author sunyj
 * @since 2020-06-04
 */
@Service("rentSettlement")
public class RentSettlementBpmServiceImpl implements ICommonBusinessService {

    private Logger logger = LoggerFactory.getLogger(this.getClass());
    @Autowired
    private IRentContractService rentContractService;

    @Autowired
    private IRentSettlementService rentSettlementService;

    @Autowired
    private IBillTypeApi billTypeApi;


    @Override
    public CommonResponse<String> afterApprovalProcessor(Long billId, Integer state,String billTypeCode) {
        logger.info("进入审批同意后回写--- billId:"+billId+"  state:"+state);
        RentSettlementEntity settlementEntity= rentSettlementService.selectById(billId);
        BigDecimal offsetMny = settlementEntity.getOffsetMny()==null?BigDecimal.ZERO:settlementEntity.getOffsetMny();//本次冲抵金额
        BigDecimal settlementMny = settlementEntity.getSettlementMny()==null?BigDecimal.ZERO:settlementEntity.getSettlementMny();//本期结算金额(不含税)
        BigDecimal settlementTaxMny = settlementEntity.getSettlementTaxMny()==null?BigDecimal.ZERO:settlementEntity.getSettlementTaxMny();//本期结算金额(含税)

        BigDecimal sumOffsetMnys = settlementEntity.getSumOffsetMny()==null?BigDecimal.ZERO:settlementEntity.getSumOffsetMny();//实际累计冲抵金额
        BigDecimal sumPayMnys = settlementEntity.getSumPayMny()==null?BigDecimal.ZERO:settlementEntity.getSumPayMny();//实际预付款金额
        //1，先查出合同
        RentContractEntity contractEntity = rentContractService.selectById(settlementEntity.getContractId());
        BigDecimal sumOffsetMny = contractEntity.getSumOffsetMny()==null?BigDecimal.ZERO:contractEntity.getSumOffsetMny();//累计冲抵金额
        BigDecimal sumSettlementMny = contractEntity.getSumSettlementMny()==null?BigDecimal.ZERO:contractEntity.getSumSettlementMny();//累计结算金额(不含税)
        BigDecimal sumSettlementTaxMny = contractEntity.getSumSettlementTaxMny()==null?BigDecimal.ZERO:contractEntity.getSumSettlementTaxMny();//累计结算金额

        if(offsetMny.compareTo(sumPayMnys.subtract(sumOffsetMnys))>0){
            return CommonResponse.error("审批回写异常!该合同冲抵金额已超出预付款金额!");
        }

        contractEntity.setSumOffsetMny(sumOffsetMny.add(offsetMny));
        contractEntity.setSumSettlementMny(sumSettlementMny.add(settlementMny));
        contractEntity.setSumSettlementTaxMny(sumSettlementTaxMny.add(settlementTaxMny));
        logger.info("业务逻辑完成--"+contractEntity.getSumOffsetMny()+"    --"+contractEntity.getSumSettlementTaxMny());

        Boolean flag = rentContractService.saveOrUpdate(contractEntity,false);
        logger.info("业务逻辑完成--返回"+flag);
        rentSettlementService.costPush(settlementEntity);
        if(flag){
            return CommonResponse.success();
        }else{
            return CommonResponse.error("审批回写异常!");
        }
    }



    @Override
    public CommonResponse<String> beforeAbstainingProcessor(Long billId, Integer state,String billTypeCode) {
        RentSettlementEntity settlementEntity = rentSettlementService.selectById(billId);
        //TO DO 结算单是否被其他引用
        CommonResponse<String>  res = billTypeApi.checkQuote(billTypeCode,billId);
        logger.info("平台返回查询被引用情况"+res.isSuccess()+"----"+res.getMsg());
        if(res.isSuccess()) {//单据未被下游单据引用
            LambdaQueryWrapper<RentSettlementEntity> lambdachange = Wrappers.<RentSettlementEntity>lambdaQuery();
            lambdachange.eq(RentSettlementEntity::getContractId, settlementEntity.getContractId());
            lambdachange.eq(RentSettlementEntity::getOrgId, settlementEntity.getOrgId());
            lambdachange.gt(RentSettlementEntity::getCreateTime, settlementEntity.getCreateTime());
            lambdachange.ne(RentSettlementEntity::getId,billId);
            lambdachange.in(RentSettlementEntity::getBillState, BillStateEnum.PASSED_STATE.getBillStateCode(),BillStateEnum.COMMITED_STATE.getBillStateCode());
            int num = rentSettlementService.count(lambdachange);
            if (num > 0) {
                return CommonResponse.error("审批回写异常!该合同不是最新的结算日期，不能回退!");
            } else {
                return CommonResponse.success();
            }
        }else{
            return CommonResponse.error(res.getMsg());
        }
    }

    @Override
    public CommonResponse<String> afterAbstainingProcessor(Long billId, Integer state,String billTypeCode) {
        logger.info("进入同意后回写--- billId:"+billId+"  state:"+state);
        RentSettlementEntity settlementEntity= rentSettlementService.selectById(billId);
        BigDecimal offsetMny = settlementEntity.getOffsetMny()==null?BigDecimal.ZERO:settlementEntity.getOffsetMny();//本次冲抵金额
        BigDecimal settlementMny = settlementEntity.getSettlementMny()==null?BigDecimal.ZERO:settlementEntity.getSettlementMny();//本期结算金额(不含税)
        BigDecimal settlementTaxMny = settlementEntity.getSettlementTaxMny()==null?BigDecimal.ZERO:settlementEntity.getSettlementTaxMny();//本期结算金额(含税)

        //1，先查出合同
        RentContractEntity contractEntity = rentContractService.selectById(settlementEntity.getContractId());
        BigDecimal sumOffsetMny = contractEntity.getSumOffsetMny()==null?BigDecimal.ZERO:contractEntity.getSumOffsetMny();//累计冲抵金额
        BigDecimal sumSettlementMny = contractEntity.getSumSettlementMny()==null?BigDecimal.ZERO:contractEntity.getSumSettlementMny();//累计结算金额(不含税)
        BigDecimal sumSettlementTaxMny = contractEntity.getSumSettlementTaxMny()==null?BigDecimal.ZERO:contractEntity.getSumSettlementTaxMny();//累计结算金额

        //弃审回写合同
        contractEntity.setSumOffsetMny(sumOffsetMny.subtract(offsetMny));
        contractEntity.setSumSettlementMny(sumSettlementMny.subtract(settlementMny));
        contractEntity.setSumSettlementTaxMny(sumSettlementTaxMny.subtract(settlementTaxMny));

        //弃审回写结算单上对应的金额，与合同保持一致
        logger.info("业务逻辑完成--"+contractEntity.getSumOffsetMny()+"    --"+contractEntity.getSumSettlementTaxMny());
        Boolean flag = rentContractService.saveOrUpdate(contractEntity,false);
        logger.info("业务逻辑完成--返回"+flag);
        //删除成本中心数据, 更新关联状态为未关联
        rentSettlementService.pullCost(billId);
        if(flag){
            return CommonResponse.success();
        }else{
            return CommonResponse.error("审批回写异常!");
        }
    }
}

==> ejc-rmat-impl-3.0.0-20220921.070016-74-sources.jar: com/ejianc/business/rmat/service/impl/RentSettlementBpmServiceImpl.java <==
package com.ejianc.business.rmat.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.ejianc.business.rmat.bean.RentContractEntity;
import com.ejianc.business.rmat.bean.RentSettlementEntity;
import com.ejianc.business.rmat.service.IRentContractService;
import com.ejianc.business.rmat.service.IRentSettlementService;
import com.ejianc.foundation.support.api.IBillTypeApi;
import com.ejianc.framework.core.response.BillStateEnum;
import com.ejianc.framework.core.response.CommonResponse;
import com.ejianc.framework.skeleton.billState.service.ICommonBusinessService;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;

/**
 * <p>
 * 设备合同结算单审批操作后
 * </p>
 *
 * @author sunyj
 * @since 2020-06-04
 */
@Service("rentSettlement")
public class RentSettlementBpmServiceImpl implements ICommonBusinessService {

    private Logger logger = LoggerFactory.getLogger(this.getClass());
    @Autowired
    private IRentContractService rentContractService;

    @Autowired
    private IRentSettlementService rentSettlementService;

    @Autowired
    private IBillTypeApi billTypeApi;


    
    @Override
    public CommonResponse<String> afterApprovalProcessor(Long billId, Integer state,String billTypeCode) {
        logger.info("进入审批同意后回写--- billId:"+billId+"  state:"+state);
        RentSettlementEntity settlementEntity= rentSettlementService.selectById(billId);
        BigDecimal offsetMny = settlementEntity.getOffsetMny()==null?BigDecimal.ZERO:settlementEntity.getOffsetMny();//本次冲抵金额
        BigDecimal settlementMny = settlementEntity.getSettlementMny()==null?BigDecimal.ZERO:settlementEntity.getSettlementMny();//本期结算金额(不含税)
        BigDecimal settlementTaxMny = settlementEntity.getSettlementTaxMny()==null?BigDecimal.ZERO:settlementEntity.getSettlementTaxMny();//本期结算金额(含税)

        BigDecimal sumOffsetMnys = settlementEntity.getSumOffsetMny()==null?BigDecimal.ZERO:settlementEntity.getSumOffsetMny();//实际累计冲抵金额
        BigDecimal sumPayMnys = settlementEntity.getSumPayMny()==null?BigDecimal.ZERO:settlementEntity.getSumPayMny();//实际预付款金额
        //1，先查出合同
        RentContractEntity contractEntity = rentContractService.selectById(settlementEntity.getContractId());
        BigDecimal sumOffsetMny = contractEntity.getSumOffsetMny()==null?BigDecimal.ZERO:contractEntity.getSumOffsetMny();//累计冲抵金额
        BigDecimal sumSettlementMny = contractEntity.getSumSettlementMny()==null?BigDecimal.ZERO:contractEntity.getSumSettlementMny();//累计结算金额(不含税)
        BigDecimal sumSettlementTaxMny = contractEntity.getSumSettlementTaxMny()==null?BigDecimal.ZERO:contractEntity.getSumSettlementTaxMny();//累计结算金额

        if(offsetMny.compareTo(sumPayMnys.subtract(sumOffsetMnys))>0){
            return CommonResponse.error("审批回写异常!该合同冲抵金额已超出预付款金额!");
        }

        contractEntity.setSumOffsetMny(sumOffsetMny.add(offsetMny));
        contractEntity.setSumSettlementMny(sumSettlementMny.add(settlementMny));
        contractEntity.setSumSettlementTaxMny(sumSettlementTaxMny.add(settlementTaxMny));
        logger.info("业务逻辑完成--"+contractEntity.getSumOffsetMny()+"    --"+contractEntity.getSumSettlementTaxMny());

        Boolean flag = rentContractService.saveOrUpdate(contractEntity,false);
        logger.info("业务逻辑完成--返回"+flag);
        if(!flag) {
            return CommonResponse.error("审批回写异常!");
        }

        if(settlementEntity.getBillState()==BillStateEnum.COMMITED_STATE.getBillStateCode()||settlementEntity.getBillState()==BillStateEnum.PASSED_STATE.getBillStateCode()){
            rentSettlementService.costPush(settlementEntity);
        }

        return CommonResponse.success();
    }


    
    @Override
    public CommonResponse<String> beforeAbstainingProcessor(Long billId, Integer state,String billTypeCode) {
        RentSettlementEntity settlementEntity = rentSettlementService.selectById(billId);
        //TO DO 结算单是否被其他引用
        CommonResponse<String>  res = billTypeApi.checkQuote(billTypeCode,billId);
        logger.info("平台返回查询被引用情况"+res.isSuccess()+"----"+res.getMsg());
        if(res.isSuccess()) {//单据未被下游单据引用
            LambdaQueryWrapper<RentSettlementEntity> lambdachange = Wrappers.<RentSettlementEntity>lambdaQuery();
            lambdachange.eq(RentSettlementEntity::getContractId, settlementEntity.getContractId());
            lambdachange.eq(RentSettlementEntity::getOrgId, settlementEntity.getOrgId());
            lambdachange.gt(RentSettlementEntity::getCreateTime, settlementEntity.getCreateTime());
            lambdachange.ne(RentSettlementEntity::getId,billId);
            lambdachange.in(RentSettlementEntity::getBillState, BillStateEnum.PASSED_STATE.getBillStateCode(),BillStateEnum.COMMITED_STATE.getBillStateCode());
            int num = rentSettlementService.count(lambdachange);
            if (num > 0) {
                return CommonResponse.error("审批回写异常!该合同不是最新的结算日期，不能回退!");
            } else {
                return CommonResponse.success();
            }
        }else{
            return CommonResponse.error(res.getMsg());
        }
    }

    @Override
    public CommonResponse<String> afterAbstainingProcessor(Long billId, Integer state,String billTypeCode) {
        logger.info("进入同意后回写--- billId:"+billId+"  state:"+state);
        RentSettlementEntity settlementEntity= rentSettlementService.selectById(billId);
        BigDecimal offsetMny = settlementEntity.getOffsetMny()==null?BigDecimal.ZERO:settlementEntity.getOffsetMny();//本次冲抵金额
        BigDecimal settlementMny = settlementEntity.getSettlementMny()==null?BigDecimal.ZERO:settlementEntity.getSettlementMny();//本期结算金额(不含税)
        BigDecimal settlementTaxMny = settlementEntity.getSettlementTaxMny()==null?BigDecimal.ZERO:settlementEntity.getSettlementTaxMny();//本期结算金额(含税)

        //1，先查出合同
        RentContractEntity contractEntity = rentContractService.selectById(settlementEntity.getContractId());
        BigDecimal sumOffsetMny = contractEntity.getSumOffsetMny()==null?BigDecimal.ZERO:contractEntity.getSumOffsetMny();//累计冲抵金额
        BigDecimal sumSettlementMny = contractEntity.getSumSettlementMny()==null?BigDecimal.ZERO:contractEntity.getSumSettlementMny();//累计结算金额(不含税)
        BigDecimal sumSettlementTaxMny = contractEntity.getSumSettlementTaxMny()==null?BigDecimal.ZERO:contractEntity.getSumSettlementTaxMny();//累计结算金额

        //弃审回写合同
        contractEntity.setSumOffsetMny(sumOffsetMny.subtract(offsetMny));
        contractEntity.setSumSettlementMny(sumSettlementMny.subtract(settlementMny));
        contractEntity.setSumSettlementTaxMny(sumSettlementTaxMny.subtract(settlementTaxMny));

        //弃审回写结算单上对应的金额，与合同保持一致
        logger.info("业务逻辑完成--"+contractEntity.getSumOffsetMny()+"    --"+contractEntity.getSumSettlementTaxMny());
        Boolean flag = rentContractService.saveOrUpdate(contractEntity,false);
        logger.info("业务逻辑完成--返回"+flag);
        if(!flag) {
            return CommonResponse.error("审批回写异常!");
        }

        // 清空来源主键
        LambdaUpdateWrapper<RentSettlementEntity> wrapper = new LambdaUpdateWrapper<>();
        wrapper.set(RentSettlementEntity::getSourceId, null);
        wrapper.eq(RentSettlementEntity::getId, billId);
        rentSettlementService.update(wrapper);

        //删除成本中心数据, 更新关联状态为未关联
        rentSettlementService.pullCost(billId);

        return CommonResponse.success();
    }
}
